#[repr(C)]pub struct CascadeLevel(u8);Expand description
The cascade level these rules are relevant at, as per13.
We store them as a bitfield with:
- Shadow cascade order (4 bits). See ShadowCascadeOrder for details.
- Importance bit. Whether the declaration was !important or not.
- The CascadeOrigin of the declaration as per 1.
Presentational hints for SVG and HTML are in the “author-level zero-specificity” level, that is, right after user rules, and before author rules.
See also 4 for the Shadow DOM bits. We rely on the invariant that rules from outside the tree the element is in can’t affect the element.
The opposite is not true (i.e., :host and ::slotted) from an “inner” shadow tree may affect an element connected to the document or an “outer” shadow tree.
Tuple Fields
0: u8Implementations
Sourceimpl CascadeLevel
impl CascadeLevel
Sourcepub const ORIGIN_BITS: Self
pub const ORIGIN_BITS: Self
The three bits that represent the CascadeOrigin.
Sourcepub const CASCADE_ORDER_BITS: Self
pub const CASCADE_ORDER_BITS: Self
The three bits for cascade order absolute value. If you change this, please change CASCADE_ORDER_SHIFT accordingly.
Sourcepub const CASCADE_ORDER_SIGN: Self
pub const CASCADE_ORDER_SIGN: Self
The bit for the sign.
Sourceimpl CascadeLevel
impl CascadeLevel
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<Self>
pub const fn from_bits(bits: u8) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> Self
pub const fn from_bits_truncate(bits: u8) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> Self
pub const fn from_bits_retain(bits: u8) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl CascadeLevel
impl CascadeLevel
Sourcepub const fn iter(&self) -> Iter<CascadeLevel>
pub const fn iter(&self) -> Iter<CascadeLevel>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<CascadeLevel>
pub const fn iter_names(&self) -> IterNames<CascadeLevel>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl CascadeLevel
impl CascadeLevel
Sourcepub const CASCADE_ORDER_SHIFT: usize = 4usize
pub const CASCADE_ORDER_SHIFT: usize = 4usize
The shift that we apply to the cascade order.
Sourcepub const SAME_TREE_AUTHOR_NORMAL: Self
pub const SAME_TREE_AUTHOR_NORMAL: Self
The author level at the same tree. Here for convenience to avoid duplicating it from C++.
Sourcepub fn new(origin: CascadeOrigin) -> Self
pub fn new(origin: CascadeOrigin) -> Self
Returns a cascade level with a given origin.
Sourcepub fn origin(self) -> CascadeOrigin
pub fn origin(self) -> CascadeOrigin
Returns the cascade origin.
Sourcepub fn unimportant(self) -> Self
pub fn unimportant(self) -> Self
Convert this level from “important” to “non-important”.
Sourcepub fn guard<'a>(
&self,
guards: &'a StylesheetGuards<'a>,
) -> &'a SharedRwLockReadGuard<'a>
pub fn guard<'a>( &self, guards: &'a StylesheetGuards<'a>, ) -> &'a SharedRwLockReadGuard<'a>
Select a lock guard for this level
Returns the cascade level for author important declarations from the same tree as the element.
Returns the cascade level for author normal declarations from the same tree as the element.
Sourcepub fn is_important(&self) -> bool
pub fn is_important(&self) -> bool
Returns whether this cascade level represents important rules of some sort.
Sourcepub fn importance(&self) -> Importance
pub fn importance(&self) -> Importance
Returns the importance relevant for this rule. Pretty similar to
is_important.
Sourcepub fn is_animation(&self) -> bool
pub fn is_animation(&self) -> bool
Returns whether this cascade level represents an animation rules.
fn shadow_order(self) -> ShadowCascadeOrder
Returns an author normal cascade level with the given shadow cascade order.